@@ -1,5 +1,5 @@
-# Gufw 19.04.0 - http://gufw.org
-# Copyright (C) 2008-2016 Marcos Alvarez Costales https://launchpad.net/~costales
+# Gufw - https://costales.github.io/projects/gufw/
+# Copyright (C) 2008-2020 Marcos Alvarez Costales https://costales.github.io
 #
 # Gufw is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,12 +16,14 @@
 # information.
 
 import os, sys
-
+from stat import *
 
 class Instance:
     def __init__(self):
         self.pid_file = '/tmp/gufw.pid'
         self._check_is_root()
+        self._check_dir_writable('/etc')
+        self._check_dir_writable('/lib')
         self._check_instance()
         self._start_application()
     
@@ -34,6 +36,21 @@ class Instance:
             dialog.destroy()
             exit(0)
     
+    def _check_dir_writable(self, directory):
+        if bin(os.stat(directory)[ST_MODE])[-5] == '0' and bin(os.stat(directory)[ST_MODE])[-2] == '0': # get chmod /etc
+            return
+        
+        from gi.repository import Gtk
+        import gettext
+        from gettext import gettext as _
+        gettext.textdomain('gufw')
+        
+        dialog = Gtk.MessageDialog(None, 0, Gtk.MessageType.INFO, Gtk.ButtonsType.OK, _("Error: %s is writable" % directory))
+        dialog.format_secondary_text(_("Your %s directory is writable.\nFix it running from Terminal:" % directory) + "\n\nsudo chmod 755 " + directory)
+        dialog.run()
+        dialog.destroy()
+        exit(0)
+
     def _check_instance(self):
         if not os.path.isfile(self.pid_file):
             return
