@@ -1,5 +1,5 @@
-# Gufw 19.04.0 - http://gufw.org
-# Copyright (C) 2008-2016 Marcos Alvarez Costales https://launchpad.net/~costales
+# Gufw - https://costales.github.io/projects/gufw/
+# Copyright (C) 2008-2020 Marcos Alvarez Costales https://costales.github.io
 #
 # Gufw is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -66,8 +66,8 @@ class Frontend():
     
     
     # RULES > For current profile!
-    def get_rules(self):
-        return self.firewall.get_rules()
+    def get_rules(self, force_fw_on=True):
+        return self.firewall.get_rules(force_fw_on)
     
     def get_number_rules(self):
         return self.firewall.get_number_rules()
