@@ -1,5 +1,5 @@
-# Gufw 19.04.0 - http://gufw.org
-# Copyright (C) 2008-2016 Marcos Alvarez Costales https://launchpad.net/~costales
+# Gufw - https://costales.github.io/projects/gufw/
+# Copyright (C) 2008-2020 Marcos Alvarez Costales https://costales.github.io
 #
 # Gufw is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@ class Backend():
             proc = subprocess.Popen(cmd, shell=False, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
         stdout,stderr=proc.communicate()
         
-        if stderr: # Error
+        if stderr and not stderr.decode().startswith("WARN") and not stderr.decode().startswith("DEBUG"): # Error
             while stderr[-1:] == '\n':
                 stderr = stderr[:-1]
             return stderr.decode('utf-8')
@@ -475,7 +475,7 @@ class Backend():
         ips = cmd.split('\n')
         
         if len(ips) > 0:
-            return ips[0]
+            return ips[0].strip()
         else:
             return '127.0.0.1'
     
